@@ -10,7 +10,7 @@
  * 
  * The Original Code is Libvoikko: Library of natural language processing tools.
  * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
- * Portions created by the Initial Developer are Copyright (C) 2010
+ * Portions created by the Initial Developer are Copyright (C) 2010 - 2013
  * the Initial Developer. All Rights Reserved.
  * 
  * Alternatively, the contents of this file may be used under the terms of
@@ -35,6 +35,12 @@
 
 #ifdef HAVE_HFST
 #include "spellchecker/HfstSuggestion.hpp"
+#include "spellchecker/HfstSpeller.hpp"
+#endif
+
+#ifdef HAVE_EXPERIMENTAL_VFST
+#include "spellchecker/VfstSpeller.hpp"
+#include "spellchecker/VfstSuggestion.hpp"
 #endif
 
 using namespace std;
@@ -45,20 +51,30 @@ SuggestionGenerator * SuggestionGeneratorFactory::getSuggestionGenerator(
 	                             voikko_options_t * voikkoOptions,
 	                             SuggestionType suggestionType)
 	                              throw(setup::DictionaryException) {
-	string backend = voikkoOptions->dictionary.getSuggestionBackend();
+	string backend = voikkoOptions->dictionary.getSuggestionBackend().getBackend();
 	if (backend == "FinnishSuggestionStrategy(currentAnalyzer)") {
 		if (suggestionType == SUGGESTION_TYPE_OCR) {
-			return new SuggestionStrategyOcr(voikkoOptions->morAnalyzer, 1500);
+			return new SuggestionStrategyOcr(voikkoOptions->morAnalyzer, 2000);
 		}
 		else {
-			return new SuggestionStrategyTyping(voikkoOptions->morAnalyzer, 590);
+			return new SuggestionStrategyTyping(voikkoOptions->morAnalyzer, 800);
 		}
 	} else if (backend == "null") {
 		return new SuggestionGeneratorNull();
 	}
 	#ifdef HAVE_HFST
 	if (backend == "hfst") {
-		return new HfstSuggestion(voikkoOptions->dictionary.getMorPath(), voikkoOptions);
+		const HfstSpeller * hfstSpeller = dynamic_cast<HfstSpeller *>(voikkoOptions->speller);
+		return new HfstSuggestion(hfstSpeller->speller);
+	}
+	#endif
+	#ifdef HAVE_EXPERIMENTAL_VFST
+	if (backend == "vfst") {
+		const VfstSpeller * vfstSpeller = dynamic_cast<VfstSpeller *>(voikkoOptions->speller);
+		if (!vfstSpeller) {
+			throw setup::DictionaryException("VFST suggestion generator works only with VFST speller");
+		}
+		return new VfstSuggestion(vfstSpeller->transducer, voikkoOptions->dictionary.getMorBackend().getPath());
 	}
 	#endif
 	throw setup::DictionaryException("Failed to create suggestion generator because of unknown suggestion generator backend");
